@@ -1,8 +1,8 @@
 import numpy as np
 from .viewer import Viewer
 
-def open_new_viewer(points):
-    viewer = Viewer(points)
+def open_new_viewer(points, aggregated_frames):
+    viewer = Viewer(points, aggregated_frames)
     return viewer
 
 def open_viewer(points, point_size=0.005):
